@@ -1,36 +1,33 @@
 #include "version.hpp"
 
-#include <pybind11/pybind11.h>
-#include <pybind11/numpy.h>
+#include <nanobind/nanobind.h>
+#include <nanobind/ndarray.h>
 #include <mapbox/earcut.hpp>
 
+#include <array>
 #include <iostream>
 #include <vector>
 
 #define IDENT_TO_STR(x) #x
 #define MACRO_TO_STR(x) IDENT_TO_STR(x)
 
-namespace py = pybind11;
+namespace nb = nanobind ;
+
+template<typename CoordT>
+using VertexArray = nb::ndarray<CoordT, nb::shape<-1, 2>, nb::device::cpu>;
+
+template<typename IndexT>
+using IndexArray = nb::ndarray<IndexT, nb::shape<-1>, nb::device::cpu>;
+
 
 //! vertices: (nverts, 2) numpy array
 //! ring_end_indices: the end indices for each ring. The last value must be equal to the number of input vertices.
 template<typename CoordT, typename IndexT>
-py::array_t<IndexT> triangulate(py::array_t<CoordT> vertices, py::array_t<IndexT> ring_end_indices)
+auto triangulate(const VertexArray<CoordT>& vertices, const IndexArray<IndexT>& ring_end_indices)
 {
-    if (vertices.ndim() != 2)
-    {
-        throw std::domain_error("The shape of vertices is not (nverts, 2)!");
-    }
-    if (ring_end_indices.ndim() != 1)
-    {
-        throw std::domain_error("ring_end_indices must be one-dimensional!");
-    }
-    auto v = vertices.unchecked();
-    if (v.shape(1) != 2)
-    {
-        throw std::domain_error("The second dimension of vertices is not 2!");
-    }
-    auto r = ring_end_indices.template unchecked<1>();
+
+    auto v = vertices;
+    auto r = ring_end_indices;
     const auto num_rings = r.shape(0);
     const auto num_verts = v.shape(0);
     if (num_rings > 0)
@@ -46,6 +43,7 @@ py::array_t<IndexT> triangulate(py::array_t<CoordT> vertices, py::array_t<IndexT
     }
     using Point = std::array<CoordT, 2>;
     std::vector<std::vector<Point>> polygon;
+    polygon.reserve(num_verts);
     for (int ring = 0; ring < r.shape(0); ++ring)
     {
         const int start = ring == 0 ? 0 : r(ring - 1);
@@ -61,36 +59,31 @@ py::array_t<IndexT> triangulate(py::array_t<CoordT> vertices, py::array_t<IndexT
         std::vector<Point> ring_verts;
         for (int idx = start; idx < end; ++idx)
         {
-            ring_verts.push_back(Point{
-                v(idx, 0),
-                v(idx, 1)
-            });
+            ring_verts.push_back({v(idx, 0), v(idx, 1)});
         }
         polygon.push_back(ring_verts);
     }
 
     std::vector<IndexT> indices = mapbox::earcut<IndexT>(polygon);
 
-    return py::array(
-        indices.size(),
-        indices.data()
-    );
+    return nb::ndarray<IndexT, nb::numpy, nb::shape<-1>>(
+        indices.data(),
+        {indices.size()}
+    ).cast();
 }
 
-PYBIND11_MODULE(mapbox_earcut, m)
+NB_MODULE(_core, m)
 {
     m.attr("__version__") = MACRO_TO_STR(VERSION_MAJOR) "." MACRO_TO_STR(VERSION_MINOR) "." MACRO_TO_STR(VERSION_PATCH);
     m.doc() = R"pbdoc(
         Python bindings to mapbox/earcut.hpp
         -----------------------
 
-        .. currentmodule:: mapbox_earcut
+        .. currentmodule:: mapbox_earcut._core
 
         .. autosummary::
            :toctree: _generate
 
-           add
-           subtract
     )pbdoc";
 
     m.def("triangulate_int32", &triangulate<int32_t, uint32_t>);
