@@ -10,64 +10,64 @@ def test_valid_triangulation_float32():
     result = earcut.triangulate_float32(verts, rings)
 
     assert result.dtype == np.uint32
-    assert result.shape == (3, )
-    assert np.all(result == np.array([1, 2, 0]))
+    assert result.shape == (3,)
+    assert np.array_equal(result, np.array([1, 2, 0]))
 
 
 def test_valid_triangulation_float64():
     verts = np.array([[0, 0], [1, 0], [1, 1]], dtype=np.float64).reshape(-1, 2)
     rings = np.array([3])
 
-    result = earcut.triangulate_float32(verts, rings)
+    result = earcut.triangulate_float64(verts, rings)
 
     assert result.dtype == np.uint32
-    assert result.shape == (3, )
-    assert np.all(result == np.array([1, 2, 0]))
+    assert result.shape == (3,)
+    assert np.array_equal(result, np.array([1, 2, 0]))
 
 
 def test_valid_triangulation_int32():
     verts = np.array([[0, 0], [1, 0], [1, 1]], dtype=np.int32).reshape(-1, 2)
     rings = np.array([3])
 
-    result = earcut.triangulate_float32(verts, rings)
+    result = earcut.triangulate_int32(verts, rings)
 
     assert result.dtype == np.uint32
-    assert result.shape == (3, )
-    assert np.all(result == np.array([1, 2, 0]))
-
-
-def test_inverted_vertex_order():
-    verts = np.array(
-        list(reversed([[0, 0], [1, 0], [1, 1]])), dtype=np.int32).reshape(
-            -1, 2)
-    rings = np.array([3])
-
-    result = earcut.triangulate_float32(verts, rings)
-
-    assert result.dtype == np.uint32
-    assert result.shape == (3, )
-    assert np.all(result == np.array([1, 0, 2]))
-
-
-def test_no_triangles():
-    verts = np.array([[0, 0], [1, 0], [1, 1]], dtype=np.int32).reshape(-1, 2)
-    rings = np.array([2, 3])
-
-    result = earcut.triangulate_float32(verts, rings)
-
-    assert result.dtype == np.uint32
-    assert result.shape == (0, )
+    assert result.shape == (3,)
+    assert np.array_equal(result, np.array([1, 2, 0]))
 
 
 def test_valid_triangulation_int64():
     verts = np.array([[0, 0], [1, 0], [1, 1]], dtype=np.int64).reshape(-1, 2)
     rings = np.array([3])
 
-    result = earcut.triangulate_float32(verts, rings)
+    result = earcut.triangulate_int64(verts, rings)
 
     assert result.dtype == np.uint32
-    assert result.shape == (3, )
-    assert np.all(result == np.array([1, 2, 0]))
+    assert result.shape == (3,)
+    assert np.array_equal(result, np.array([1, 2, 0]))
+
+
+def test_inverted_vertex_order():
+    verts = np.array(list(reversed([[0, 0], [1, 0], [1, 1]])), dtype=np.int32).reshape(
+        -1, 2
+    )
+    rings = np.array([3])
+
+    result = earcut.triangulate_int32(verts, rings)
+
+    assert result.dtype == np.uint32
+    assert result.shape == (3,)
+    assert np.array_equal(result, np.array([1, 0, 2]))
+
+
+def test_no_triangles():
+    verts = np.array([[0, 0], [1, 0], [1, 1]], dtype=np.int32).reshape(-1, 2)
+    rings = np.array([2, 3])
+
+    result = earcut.triangulate_int32(verts, rings)
+
+    assert result.dtype == np.uint32
+    assert result.shape == (0,)
 
 
 def test_end_index_too_large():
@@ -124,4 +124,4 @@ def test_empty_data():
 
     result = earcut.triangulate_float32(verts, rings)
 
-    assert result.shape == (0, )
+    assert result.shape == (0,)
